# Awesome ACTUS Library

A modular user-friendly Python Library for Financial Modelling with the ACTUS Standard.

## Features

- Define and simulate ACTUS contracts and portfolios
- Generate complete event streams from ACTUS contracts
- Perform **Income**, **Liquidity**, and **Value** analysis
- Visualize cash flows for single contracts or full portfolios

## Install

```bash
pip install awesome-actus-lib
```

## Documentation
Visit the [documentation site](https://awesomeactuslibrarydoc.vercel.app) for:

Architecture Overview
How-to guides and examples
Full class documentations
Complete analysis examples from contract definition to analysis results

## ACTUS Foundation

This library is based on the ACTUS Financial Contract Standard. Learn more at:

🌐 https://www.actusfrf.org

## Author & Contributions

Maintained by [@maierdon](https://github.com/maierdon).

We welcome contributions via pull request. For larger design suggestions, contact the author or open a discussion thread.
If you find errors or bugs please report them as github issues.